#[non_exhaustive]pub enum AgentModel {
String(String),
Config {
id: String,
speed: Option<ModelSpeed>,
},
}Available on crate feature
managed-agents-preview only.Expand description
Model identifier. Wire form is either a bare string or a
{id, speed} object.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
String(String)
Bare model string. Use this for the common case where you don’t need to override the inference speed.
Config
Object form with explicit speed.
Implementations
Sourceimpl AgentModel
impl AgentModel