#[non_exhaustive]pub enum MemoryStoreAccess {
ReadOnly,
ReadWrite,
}Available on crate feature
managed-agents-preview only.Expand description
Access mode for a MemoryStoreResource.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ReadOnly
Reference material the agent can read but not write.
ReadWrite
Default. Writes produce new memory versions attributed to the session.