pub enum ContentDelta {
Known(KnownContentDelta),
Other(Value),
}Expand description
One delta update inside a KnownStreamEvent::ContentBlockDelta.
Forward-compatible wrapper around KnownContentDelta.
Variants
Known(KnownContentDelta)
A delta whose type is recognized by this SDK version.
Other(Value)
A delta whose type is not recognized; the raw JSON is preserved.
Implementations
Sourceimpl ContentDelta
impl ContentDelta
Sourcepub fn known(&self) -> Option<&KnownContentDelta>
pub fn known(&self) -> Option<&KnownContentDelta>
If this is a known delta, return the inner KnownContentDelta.