#[non_exhaustive]pub enum ToolChoice {
Auto {
disable_parallel_tool_use: Option<bool>,
},
Any {
disable_parallel_tool_use: Option<bool>,
},
Tool {
name: String,
disable_parallel_tool_use: Option<bool>,
},
None,
}Expand description
How (or whether) the model should invoke a tool on this turn.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Auto
Default: the model decides whether and which tool to use.
Fields
Any
The model must use a tool, but may choose which one.
Tool
The model must use the named tool.
Fields
None
The model must not use any tool.
Implementations
Sourceimpl ToolChoice
impl ToolChoice