#[non_exhaustive]pub struct Paginated<T> {
pub data: Vec<T>,
pub has_more: bool,
pub first_id: Option<String>,
pub last_id: Option<String>,
}Expand description
One page of items returned from a paginated list endpoint.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.data: Vec<T>Items on this page.
has_more: boolWhether more pages exist after this one.
first_id: Option<String>ID of the first item on this page (cursor for before_id).
last_id: Option<String>ID of the last item on this page (cursor for after_id).
Implementations
Sourceimpl<T> Paginated<T>
impl<T> Paginated<T>
Sourcepub fn next_after(&self) -> Option<&str>
pub fn next_after(&self) -> Option<&str>
Cursor for the next page (forward direction): the last_id of this
page, suitable for the next request’s after_id parameter. Returns
None if there are no more pages.
Sourcepub fn next_before(&self) -> Option<&str>
pub fn next_before(&self) -> Option<&str>
Cursor for the previous page (backward direction): the first_id
of this page, for the next request’s before_id parameter.