#[non_exhaustive]pub enum TrustGrantStatus {
Active,
Pending,
Rejected,
}Available on crate feature
user-profiles only.Expand description
Status of a single trust grant on a UserProfile.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Active
Grant is active and the user has been verified.
Pending
Enrollment has been started but not yet completed.
Rejected
Enrollment was attempted and rejected.